==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpSearchResultWidget.java <==
package io.qt.help;


/**
 * <p>Text browser to display search results</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpsearchresultwidget.html">QHelpSearchResultWidget</a></p>
 */
public final class QHelpSearchResultWidget extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpSearchResultWidget.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresultwidget.html#requestShowLink">QHelpSearchResultWidget::requestShowLink(QUrl)</a></p>
     */
    public final Signal1<io.qt.core.QUrl> requestShowLink = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchresultwidget.html#linkAt">QHelpSearchResultWidget::linkAt(QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl linkAt(io.qt.core.QPoint point){
        return linkAt_native_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(point));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl linkAt_native_cref_QPoint(long __this__nativeId, long point);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchResultWidget(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.2.1-sources.jar: io/qt/help/QHelpSearchResultWidget.java <==
package io.qt.help;


/**
 * <p>Text browser to display search results</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpsearchresultwidget.html">QHelpSearchResultWidget</a></p>
 */
public final class QHelpSearchResultWidget extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpSearchResultWidget.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresultwidget.html#requestShowLink">QHelpSearchResultWidget::requestShowLink(QUrl)</a></p>
     */
    public final Signal1<io.qt.core.QUrl> requestShowLink = new Signal1<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchresultwidget.html#linkAt">QHelpSearchResultWidget::linkAt(QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl linkAt(io.qt.core.QPoint point){
        return linkAt_native_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(point));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl linkAt_native_cref_QPoint(long __this__nativeId, long point);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchResultWidget(QPrivateConstructor p) { super(p); } 
    
}
